/******************************************************************************
   Timer.c
   The CPU timer routines.
******************************************************************************/
#include <MC9S12E128.h>  // Derivative information
#include "Timer.h"
#include "SCI0.h"

// Global Variables
extern byte Phase;
extern byte Slope;
extern word Angle;
extern int  Adj;



/*****************************************************************************/
#pragma CODE_SEG NON_BANKED
interrupt void T0C6_Int(void)
{
  if (Angle > 5)  // If unsynchronized by a lot, slam it into sync
  {
    Phase = 1;
    Slope = 1;
    Angle = 0;
  }

/* Adjustment sensed at zero crossing and executed at peak */
  if (Angle != 0)  // I slightly out of sync, adjust gently at peak
  {
    if (Phase)
      Adj = 1;
    else
      Adj = -1;
  }

/* Check for locked condition */
  if (Angle < 2)
  {
    PTP_PTP0 = 1;  // Red LED on
    //SCI0_PutQueue("_");
  }
  else
  {
    PTP_PTP0 = 0;  // Red LED off
    //SCI0_PutQueue("|");
  }

  TIM0_TFLG1_C6F = 1;  // Clear timer 0 channel 6 flag
}
#pragma CODE_SEG DEFAULT

/*****************************************************************************/
void InitT0C6(void)
{
  TIM0_TSCR1 = TIM0_TSCR1_TEN_MASK;   // Enable timer 0
  TIM0_TSCR2 = 0;                     // Set prescaler to divide by 1
  TIM0_TCTL3 = TIM0_TCTL3_EDG6A_MASK; // Capture on rising edges only

  TIM0_TFLG1_C6F = 1;                 // Clear timer 0 channel 6 flag
  TIM0_TIE_C6I = 1;                   // Enable timer 0 channel 6 interrupts
}