/******************************************************************************
   main.c
   This is a classic main function. Initialization followed by an infinite
   loop. No code is executed in the main loop. It simply acts as a task
   dispatcher. Make sure all functions are non-blocking so that they all
   have a chance to run.
******************************************************************************/
#include <hidef.h>          /* common defines and macros */
#include <mc9s12e128.h>     /* derivative information */
#include "App.h"
#include "ATD.h"
#include "CPU.h"
#include "DAC.h"
#include "IO.h"
#include "PMF.h"
#include "SCI0.h"
#include "SCI1.h"
#include "SPI.h"
#include "Timer.h"



// Global Variables
extern char WaitFlags;   // Defined in CPU.c

// Global Messages
char *Msg1 = "Started Grid-Tie Program\r\n";
char *Msg2 = "Version 1.0\r\n";


void main(void)
{
  InitPLL();      // Initialize the PLL
  InitLED();      // Initialize the LED
  InitIO();       // Initialize IO
  InitSCI0();     // Initialize SCI0
  //InitSCI1();     // Initialize SCI1
  //InitSPI();      // Initialize the SPI
  InitT0C6();     // Initialize line power sync interrupt
  InitPMF();      // Initialize the PMF
  //InitDAC0();     // Initialize DAC0
  //InitDAC1();     // Initialize DAC1
  //InitATD();      // Initialize ATD

  EnableInterrupts;

  SCI0_PutQueue(Msg1);    // Opening messages
  SCI0_PutQueue(Msg2);

  WaitFlags = 0xFF;

  for(;;)
  {
    SCI0_Rx();            // Check for received characters on SCI0
    SCI0_CheckQueue();    // Check for outgoing messages for SCI0

    //SCI1_Rx();            // Check for received characters on SCI1
    //SCI1_CheckQueue();    // Check for outgoing messages for SCI1

    GoToThread1();        // Do Thread 1 State Machine
    //GoToThread2();      // Do Thread 2 State Machine
    //GoToThread3();      // Do Thread 3 State Machine
  }
}
